Version 1.1.2
-------------

-   Slow down retry rate

Version 1.1.1
-------------

-   Retry when connection to broker fails

Version 1.1.0
-------------

-   Added typehints

Version 1.0.0
-------------

-   Initial public release
